Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetProtectedProcesses ¶
GetProtectedProcesses returns the map of critical processes
func IsSystemOrDriver ¶
fixed: added generic checker that handles protection of processes better than GetProtectedProcesses it is still needed to keep GetProtectedprocess() for specific processes outside system store folders IsSystemOrDriver checks if the process provided is a critical Windows or Driver process
Types ¶
type Manager ¶
type Manager struct {
CapPercentage float64
PresetCap float64 // the user's configured cap from settings/slider
RoutineOverride bool // true when a routine is controlling the cap
IsActive bool
LastForegroundMap map[int32]time.Time // last seen foreground
AppMap map[string]AppStatus // whitelist registry
// contains filtered or unexported fields
}
func NewManager ¶
func (*Manager) IsStale ¶ added in v0.1.5
IsStale checks if a process is old enough and not currently in use
func (*Manager) StartEnforcer ¶
StartEnforcer uses adaptive frequency to handle rapid RAM spikes.
func (*Manager) StopEnforcer ¶
func (m *Manager) StopEnforcer()
Click to show internal directories.
Click to hide internal directories.